pm4py.statistics.passed\_time.log package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.passed_time.log.variants

Submodules
----------

pm4py.statistics.passed\_time.log.algorithm module
--------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.log.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.passed_time.log
   :members:
   :undoc-members:
   :show-inheritance:
